@@ -1,27 +1,45 @@
 # -*- coding: utf-8 -*-
-from A1_41 import *
+from A1_02 import *
 from gestionatr.utils import get_rec_attr
 
 
-class A1_02(A1_41):
-    """Clase que implementa C1."""
+class A1_05(A1_02):
+    """Clase que implementa M1."""
 
     steps = []
 
-    # Datos paso a102
+    # Datos paso a105
     # TODO
 
-    # Datos paso a241
+    # Datos paso a205
     @property
-    def outgoingpressuregranted(self):
-        tree = '{0}.outgoingpressuregranted'.format(self._header)
+    def finaltolltypegranted(self):
+        tree = '{0}.finaltolltypegranted'.format(self._header)
+        data = get_rec_attr(self.obj, tree, False)
+        if data not in [None, False]:
+            return data.text
+        else:
+            return False
+
+    # Datos paso a305
+    @property
+    def telephone(self):
+        tree = '{0}.telephone'.format(self._header)
+        data = get_rec_attr(self.obj, tree, False)
+        if data not in [None, False]:
+            return data.text
+        else:
+            return False
+
+    @property
+    def fax(self):
+        tree = '{0}.fax'.format(self._header)
         data = get_rec_attr(self.obj, tree, False)
         if data not in [None, False]:
             return data.text
         else:
             return False
 
-    # Datos paso a302
     @property
     def caecode(self):
         tree = '{0}.caecode'.format(self._header)
@@ -31,5 +49,4 @@ class A1_02(A1_41):
         else:
             return False
 
-    # Paso a3s02 ya soportado con los datos que tenemos
-    # Paso a402 ya soportado con los datos que tenemos
+    # Paso a405 ya soportado con los datos que tenemos
